/****************************************************  Operating Defaults  *****************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	The following defaults are assigned to structures that configure operating variables of the FPGA reference design.

	Rev History:  08-08-2018:	Inital release.

	Copyright (c) 2019  Red Rapids, Inc.

	Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
	files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,
	modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software
	is furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
	OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
	LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
	IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

****************************************************  Operating Defaults  *****************************************************/

#include "driver_functions.h"
#include "sigfpga.h"
#include "global_functions.h"
#include "channel_functions.h"

#if defined(__cplusplus)
	extern "C" {
#endif

//////////////////////////////////  Configure Transmitter & Receiver Channel Synchronizers  //////////////////////////////////

// Initialize a default structure for all channels.
s_Synchronizer SynchronizerDefault = {
	1,	// StartEvent					Event that will activate the channel. - Range: 0 (none/immediate), 1 (software trigger), 2 (hardware trigger)
	3,	// StopEvent					Event that will deactivate the channel. - Range: 0 (flow control), 1 (software trigger), 2 (hardware trigger), 3 (sample count)
	8192	// SampleCount				Number of samples to collect when sample count is selected for the synchronizer StartEvent. - Range: 0 to (2^32 - 1) in multiples of 8 bytes
};

///////////////////////////////////////////////////  Configure Interrupts  ////////////////////////////////////////////////////

// Initialize a default variable for the global interrupt mask setting.
unsigned long GlobalMaskDefault = 0;	// Global Interrupt Mask 	Enable or disable all interrupt generation from the device. - Range: 0 (disable) to 1 (enable)

// Initialize a default structure for the fault interrupt mask.
// Note: The number of active SRAM or ADC error indicators depends on specific product features.
// Note: The Alert indicator is only relevant if the port expander (FXL6408) or temperature monitor (LTC2991) are programmed to report status.
// Note: The Fan error indicator is only relevant on products equipped with an active heat sink.
s_ErrorStatus ErrorMaskDefault = {
	{ // BAR Error
		0,	// BAR0 Write Error			Generate an interrupt when a BAR0 write error is detected. - Range: 0 (disable) to 1 (enable)
		0,	// BAR0 Read Error			Generate an interrupt when a BAR0 read error is detected. - Range: 0 (disable) to 1 (enable)
		0,	// BAR2 Write Error			Generate an interrupt when a BAR2 write error is detected. - Range: 0 (disable) to 1 (enable)
		0	// BAR2 Read Error			Generate an interrupt when a BAR2 read error is detected. - Range: 0 (disable) to 1 (enable)
	},
	{ // Clock
		0,	// IDELAY Lock				Generate an interrupt when the FPGA IDELAY controller is out of lock. - Range: 0 (disable) to 1 (enable)
		0,	// Flash DCM Lock			Generate an interrupt when the Flash DCM is out of lock. - Range: 0 (disable) to 1 (enable)
		0,	// SRAM-A Lock				Generate an interrupt when the SRAM-A clock lock function produces an error. - Range: 0 (disable) to 1 (enable)
		0,	// SRAM-B Lock				Generate an interrupt when the SRAM-B clock lock function produces an error. - Range: 0 (disable) to 1 (enable)
		0,	// ADC Lock					Generate an interrupt when the ADC clock lock function produces an error. - Range: 0 (disable) to 1 (enable)
		0,	// ADC Lock					Generate an interrupt when the ADC clock lock function produces an error. - Range: 0 (disable) to 1 (enable)
		0,	// ADC Lock					Generate an interrupt when the ADC clock lock function produces an error. - Range: 0 (disable) to 1 (enable)
		0	// ADC Lock					Generate an interrupt when the ADC clock lock function produces an error. - Range: 0 (disable) to 1 (enable)
	},
	0,		//Alert						Generate an interrupt when the port expander or temperature monitor alert is active. - Range: 0 (disable) to 1 (enable)
	0		//Fan						Generate an interrupt when the fan monitor reports an error. - Range: 0 (disable) to 1 (enable)
};

// Initialize a default structure for the channel status interrupt mask.
s_ChannelIntMask ChannelMaskDefault = {
	1,	// DMA Marker						Generate an interrupt when the DMA marker is detected. - Range: 0 (disable) to 1 (enable)
	{ // Error
		0,	// Converter (ADC/DAC) Error	Generate an interrupt when a converter (ADC/DAC) error is detected. - Range: 0 (disable) to 1 (enable)
		0	// FIFO Error					Generate an interrupt when a FIFO error is detected. - Range: 0 (disable) to 1 (enable)
	}
};

#ifdef __cplusplus
}
#endif
